@@ -3,7 +3,7 @@ import unittest
 from pathlib import Path
 from unittest.mock import patch
 
-from aind_data_schema import Procedures, RawDataDescription, Processing, Subject
+from aind_data_schema import Procedures, Processing, RawDataDescription, Subject
 from aind_data_schema.base import AindCoreModel
 
 
@@ -27,10 +27,11 @@ class BaseTests(unittest.TestCase):
     def test_default_filename(self, mock_log):
         """tests that default filename returns as expected"""
 
-        test_models = [(RawDataDescription, "data_description.json"),
-                    (Procedures, "procedures.json"),
-                    (Subject, "subject.json"),
-                    (Processing, "processing.json")
+        test_models = [
+            (RawDataDescription, "data_description.json"),
+            (Procedures, "procedures.json"),
+            (Subject, "subject.json"),
+            (Processing, "processing.json"),
         ]
         for model, expected_name in test_models:
             actual_name = model.default_filename()
@@ -38,8 +39,9 @@ class BaseTests(unittest.TestCase):
 
         with self.assertRaises(IndexError):
             AindCoreModel.default_filename()
-        mock_log.assert_called_with("Unable to find direct AindCoreModel subclass for"
-                                    " <class 'aind_data_schema.base.AindCoreModel'>")
+        mock_log.assert_called_with(
+            "Unable to find direct AindCoreModel subclass for" " <class 'aind_data_schema.base.AindCoreModel'>"
+        )
 
     @patch("builtins.open", new_callable=unittest.mock.mock_open())
     def test_write_standard_file_no_prefix(self, mocked_file):
@@ -50,9 +52,7 @@ class BaseTests(unittest.TestCase):
         p.write_standard_file()
 
         mocked_file.assert_called_once_with(default_filename, "w")
-        mocked_file.return_value.__enter__().write.assert_called_once_with(
-            json_contents
-        )
+        mocked_file.return_value.__enter__().write.assert_called_once_with(json_contents)
 
     @patch("builtins.open", new_callable=unittest.mock.mock_open())
     def test_write_standard_file_with_prefix(self, mocked_file):
@@ -68,9 +68,7 @@ class BaseTests(unittest.TestCase):
         expected_file_path = str(new_path) + "_" + default_filename
 
         mocked_file.assert_called_once_with(expected_file_path, "w")
-        mocked_file.return_value.__enter__().write.assert_called_once_with(
-            json_contents
-        )
+        mocked_file.return_value.__enter__().write.assert_called_once_with(json_contents)
 
 
 if __name__ == "__main__":
